==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-62.js <==
dispMUA.arDispMUAAllocation["b"] =
{
  "beer email by beeradvocate.com" : [ "beeradvocate.png" , "http://beeradvocate.com/" ] ,
  "blue shield mail server" : [ "tumbleweed.png" ] ,
  "bueroware mailclient" : [ "softengine.png" , "http://www.softengine.de/" ] ,
  "bitdefender vshield" : [ "bitdefender.png" ] ,
  "brezosoft kmailer" : [ "kmailer.png" , "http://www.kmailer.com/" ] ,
  "bookcrossing.com" : [ "bookcrossing.png" , "http://www.bookcrossing.com/" ] ,
  "blue world lasso" : [ "lasso.png" ] ,
  "blue sky factory" : [ "blueskyfactory.png" , "http://www.blueskyfactory.com/" ] ,
  "blizzard mailer" : [ "blizzard.png" ] ,
  "bank of america" : [ "bankofamerica.png" ] ,
  "bre massmailer" : [ "bre.png" ] ,
  "bluetie mailer" : [ "bluetie.png" ] ,
  "burgerking.de" : [ "burgerking.png" , "http://www.burgerking.de/" ] ,
  "broadcasthtml" : [ "broadcasthtml.png" , "http://www.mailworkz.com/broadcast.htm" ] ,
  "bronto mail" : [ "brontomail.png" , "http://www.bronto.com/" ] ,
  "bpm beeline" : [ "bpm_beeline.png" , "http://www.bpm.ch/Produkte/beeline" ] ,
  "bplaced.net" : [ "bplaced_net.png" , "http://www.bplaced.net/" ] ,
  "bluedragon" : [ "bluedragon.png" ] ,
  "bee alerts" : [ "bee_alerts.png" ] ,
  "bossmedia" : [ "bossmedia.png" , "http://www.bossmedia.com/" ] ,
  "bofh-mail" : [ "bofhmail.png" ] ,
  "blitzmail" : [ "blitzmail.png" ] ,
  "bigsender" : [ "bigsender.png" , "http://www.craigrichards.com/software/bigsender/" ] ,
  "beos-pynr" : [ "beos.png" ] ,
  "bdoc-edit" : [ "bdoc-edit.png" , "http://www.bdoc.com/" ] ,
  "betanews" : [ "betanews.png" ] ,
  "bluewin" : [ "bluewin_ch.png" , "http://www.bluewin.ch/" ] ,
  "bloomba" : [ "bloomba.png" ] ,
  "baur-nl" : [ "baur-nl.png" , "http://www.baur.de/" ] ,
  "basilix" : [ "basilix.png" , "http://www.basilix.org/" ] ,
  "b1gmail" : [ "b1gmail.png" ] ,
  "biabam" : [ "biabam.png" ] ,
  "bemail" : [ "bemail.png" ] ,
  "bmail" : [ "bmail.png" , "http://www.beyondlogic.org/" ] ,
  "becky" : [ "becky.png" ] ,
  "barca" : [ "barca.png" ] ,
  "balsa" : [ "balsa.png" ] ,
  "blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "bbc" : [ "bbc.png" , "http://www.bbc.co.uk/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-62.js <==
dispMUA.arDispMUAAllocation["b"] =
{
  "beer email by beeradvocate.com" : [ "beeradvocate.png" , "http://beeradvocate.com/" ] ,
  "bynari insight connector" : [ "insight-connector.png" , "http://www.bynari.net/" ] ,
  "blue shield mail server" : [ "tumbleweed.png" ] ,
  "bueroware mailclient" : [ "softengine.png" , "http://www.softengine.de/" ] ,
  "bitdefender vshield" : [ "bitdefender.png" ] ,
  "brezosoft kmailer" : [ "kmailer.png" , "http://www.kmailer.com/" ] ,
  "bookcrossing.com" : [ "bookcrossing.png" , "http://www.bookcrossing.com/" ] ,
  "blue world lasso" : [ "lasso.png" ] ,
  "blue sky factory" : [ "blueskyfactory.png" , "http://www.blueskyfactory.com/" ] ,
  "britecastmailer" : [ "britemoon.png" , "http://www.britemoon.com/" ] ,
  "booklooker-mail" : [ "booklooker.png" , "http://www.booklooker.de/" ] ,
  "blizzard mailer" : [ "blizzard.png" ] ,
  "bank of america" : [ "bankofamerica.png" ] ,
  "bre massmailer" : [ "bre.png" ] ,
  "bluetie mailer" : [ "bluetie.png" ] ,
  "burgerking.de" : [ "burgerking.png" , "http://www.burgerking.de/" ] ,
  "broadcasthtml" : [ "broadcasthtml.png" , "http://www.mailworkz.com/broadcast.htm" ] ,
  "bronto mail" : [ "brontomail.png" , "http://www.bronto.com/" ] ,
  "bpm beeline" : [ "bpm_beeline.png" , "http://www.bpm.ch/Produkte/beeline" ] ,
  "bplaced.net" : [ "bplaced_net.png" , "http://www.bplaced.net/" ] ,
  "bluedragon" : [ "bluedragon.png" ] ,
  "bee alerts" : [ "bee_alerts.png" ] ,
  "bossmedia" : [ "bossmedia.png" , "http://www.bossmedia.com/" ] ,
  "bofh-mail" : [ "bofhmail.png" ] ,
  "blitzmail" : [ "blitzmail.png" ] ,
  "bigsender" : [ "bigsender.png" , "http://www.craigrichards.com/software/bigsender/" ] ,
  "beos-pynr" : [ "beos.png" ] ,
  "bdoc-edit" : [ "bdoc-edit.png" , "http://www.bdoc.com/" ] ,
  "betanews" : [ "betanews.png" ] ,
  "bluewin" : [ "bluewin_ch.png" , "http://www.bluewin.ch/" ] ,
  "bloomba" : [ "bloomba.png" ] ,
  "baur-nl" : [ "baur-nl.png" , "http://www.baur.de/" ] ,
  "basilix" : [ "basilix.png" , "http://www.basilix.org/" ] ,
  "b1gmail" : [ "b1gmail.png" ] ,
  "biabam" : [ "biabam.png" ] ,
  "bemail" : [ "bemail.png" ] ,
  "bmail" : [ "bmail.png" , "http://www.beyondlogic.org/" ] ,
  "becky" : [ "becky.png" ] ,
  "barca" : [ "barca.png" ] ,
  "balsa" : [ "balsa.png" ] ,
  "blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "bbc" : [ "bbc.png" , "http://www.bbc.co.uk/" ] ,
}
